@@ -802,6 +802,8 @@ CREATE INDEX iAExtensionLong
   ON m_assignment_ext_long (longValue) INITRANS 30;
 CREATE INDEX iAExtensionPolyString
   ON m_assignment_ext_poly (orig) INITRANS 30;
+CREATE INDEX iAExtensionPolyNorm
+    ON m_assignment_ext_poly (norm) INITRANS 30;
 CREATE INDEX iAExtensionReference
   ON m_assignment_ext_reference (targetoid) INITRANS 30;
 CREATE INDEX iAExtensionString
@@ -849,6 +851,8 @@ CREATE INDEX iExtensionLong
   ON m_object_ext_long (longValue) INITRANS 30;
 CREATE INDEX iExtensionPolyString
   ON m_object_ext_poly (orig) INITRANS 30;
+CREATE INDEX iExtensionPolyNorm
+    ON m_object_ext_poly (norm) INITRANS 30;
 CREATE INDEX iExtensionReference
   ON m_object_ext_reference (targetoid) INITRANS 30;
 CREATE INDEX iExtensionString
